@@ -10,6 +10,7 @@ from ._src import (  # noqa: E402
     allgather,
     allreduce,
     alltoall,
+    barrier,
     bcast,
     gather,
     recv,
@@ -24,6 +25,7 @@ __all__ = [
     "allgather",
     "allreduce",
     "alltoall",
+    "barrier",
     "bcast",
     "gather",
     "recv",
@@ -33,22 +35,3 @@ __all__ = [
     "send",
     "sendrecv",
 ]
-
-# TODO: remove in next minor release
-from ._deprecations import (  # noqa: E402
-    Allreduce,
-    Bcast,
-    Recv,
-    Send,
-    Sendrecv,
-)
-
-__all__.extend(
-    [
-        Allreduce,
-        Bcast,
-        Recv,
-        Send,
-        Sendrecv,
-    ]
-)
